@@ -16,7 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-__version__ = "1.0.6"
+__version__ = "1.0.7"
 __license__ = "GNU Lesser General Public License v3 or later (LGPLv3+)"
 __copyright__ = "Copyright (C) 2017-2020 Dan <https://github.com/delivrance>"
 
@@ -33,6 +33,11 @@ class ContinuePropagation(StopAsyncIteration):
     pass
 
 
-from . import types, filters, handlers, emoji
+import asyncio
+
+from . import raw, types, filters, handlers, emoji
 from .client import Client
 from .sync import idle
+
+# Save the main thread loop for future references
+main_event_loop = asyncio.get_event_loop()
